.. _guide:

============
 User Guide
============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    events
    subscribers
    dispatch
    optimization
    configuration
    extending
